<?php
session_start();
include 'config.php';

if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'admin') {
    header('Location: login.php');
    exit;
}

// إحصائيات
$stats = $conn->query("
    SELECT 
        COUNT(DISTINCT user_id) as total_candidates,
        AVG(score) as avg_score,
        MAX(score) as max_score
    FROM exam_attempts
")->fetch_assoc();
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <meta charset="UTF-8">
    <title>لوحة التحكم</title>
    <style>
        .dashboard {
            padding: 20px;
        }
        .stats-container {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 20px;
            margin-bottom: 20px;
        }
        .stat-card {
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .candidates-list {
            background: white;
            padding: 20px;
            border-radius: 8px;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ddd;
        }
    </style>
</head>
<body>
    <div class="dashboard">
        <h1>لوحة التحكم</h1>
        
        <div class="stats-container">
            <div class="stat-card">
                <h3>عدد المتقدمين</h3>
                <p><?php echo $stats['total_candidates']; ?></p>
            </div>
            <div class="stat-card">
                <h3>متوسط الدرجات</h3>
                <p><?php echo round($stats['avg_score'], 2); ?></p>
            </div>
            <div class="stat-card">
                <h3>أعلى درجة</h3>
                <p><?php echo $stats['max_score']; ?></p>
            </div>
        </div>
        
        <div class="candidates-list">
            <h2>قائمة المتقدمين</h2>
            <button onclick="exportToExcel()">تصدير إلى Excel</button>
            
            <table>
                <thead>
                    <tr>
                        <th>الاسم</th>
                        <th>البريد الإلكتروني</th>
                        <th>الدرجة</th>
                        <th>تاريخ التقدم</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $candidates = $conn->query("
                        SELECT u.username, u.email, ea.score, ea.start_time
                        FROM users u
                        JOIN exam_attempts ea ON u.id = ea.user_id
                        ORDER BY ea.start_time DESC
                    ");
                    
                    while ($row = $candidates->fetch_assoc()):
                    ?>
                    <tr>
                        <td><?php echo $row['username']; ?></td>
                        <td><?php echo $row['email']; ?></td>
                        <td><?php echo $row['score']; ?></td>
                        <td><?php echo $row['start_time']; ?></td>
                    </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        function exportToExcel() {
            // تنفيذ تصدير البيانات إلى ملف Excel
            window.location.href = 'export_excel.php';
        }
    </script>
</body>
</html>